==> media-api-1.1.5.6-gy1-20170517.031426-1-sources.jar: cn/com/duiba/tuia/media/api/dto/rsp/RspActivitySlotDto.java <==
package cn.com.duiba.tuia.media.api.dto.rsp;

import java.io.Serializable;
import java.util.Date;

/**
 * @author xuyenan
 * @createTime 2016/12/21
 */
public class RspActivitySlotDto implements Serializable {

    private static final long serialVersionUID = 1104337713819885160L;

    private Long              slotId;                                 // 广告位ID
    private String            slotName;                               // 广告位名称
    private Long              appId;                                  // 媒体ID
    private String            appName;                                // 媒体名称
    private String            msName;                                 // 广告位规格
    private Integer           amount;                                 // 数量
    private Integer           directMode;                             // 定向模式
    private Integer           slotType;                               // 广告位类型
    private Long              slotMsId;                               // 规格ID
    
    /** 广告位开启状态 */
    private Integer           enableStatus;
    
    /** 审核状态. */
    private Integer           checkStatus;
    
    /**创建时间 */
    private Date 			  gmtCreate;

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getSlotName() {
        return slotName;
    }

    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public Integer getDirectMode() {
        return directMode;
    }

    public void setDirectMode(Integer directMode) {
        this.directMode = directMode;
    }

    public String getMsName() {
        return msName;
    }

    public void setMsName(String msName) {
        this.msName = msName;
    }
    public Integer getSlotType() {
        return slotType;
    }

    
    public void setSlotType(Integer slotType) {
        this.slotType = slotType;
    }

    
    public Long getSlotMsId() {
        return slotMsId;
    }

    public void setSlotMsId(Long slotMsId) {
        this.slotMsId = slotMsId;
    }

	public Integer getEnableStatus() {
		return enableStatus;
	}

	public void setEnableStatus(Integer enableStatus) {
		this.enableStatus = enableStatus;
	}

	public Integer getCheckStatus() {
		return checkStatus;
	}

	public void setCheckStatus(Integer checkStatus) {
		this.checkStatus = checkStatus;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}
}

==> media-api-1.1.5.7-gy2-20170602.041913-2-sources.jar: cn/com/duiba/tuia/media/api/dto/rsp/RspActivitySlotDto.java <==
package cn.com.duiba.tuia.media.api.dto.rsp;

import java.io.Serializable;
import java.util.Date;



/**
 * @author xuyenan
 * @createTime 2016/12/21
 */
public class RspActivitySlotDto implements Serializable {

    private static final long serialVersionUID = 1104337713819885160L;

    private Long              slotId;                                 // 广告位ID
    private String            slotName;                               // 广告位名称
    private Long              appId;                                  // 媒体ID
    private String            appName;                                // 媒体名称
    private String            msName;                                 // 广告位规格
    private Integer           amount;                                 // 数量
    private Integer           directMode;                             // 定向模式
    private Integer           slotType;                               // 广告位类型
    private Long              slotMsId;                               // 规格ID
    
    /** 广告位开启状态 */
    private Integer           enableStatus;
    
    /** 审核状态. */
    private Integer           checkStatus;
    
    /**创建时间 */
    private Date 			  gmtCreate;
    
    /**创建时间 (yyyy-MM-dd HH:mm:ss)*/
	private String 			  gmtCreateStr;
	
	 /** 规格是否有效 */
    private Boolean           valid;
    
    /** 广告位投放方式 */
    private Integer    		  activityPutWay;

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public String getSlotName() {
        return slotName;
    }

    public void setSlotName(String slotName) {
        this.slotName = slotName;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public String getAppName() {
        return appName;
    }

    public void setAppName(String appName) {
        this.appName = appName;
    }

    public Integer getAmount() {
        return amount;
    }

    public void setAmount(Integer amount) {
        this.amount = amount;
    }

    public Integer getDirectMode() {
        return directMode;
    }

    public void setDirectMode(Integer directMode) {
        this.directMode = directMode;
    }

    public String getMsName() {
        return msName;
    }

    public void setMsName(String msName) {
        this.msName = msName;
    }
    public Integer getSlotType() {
        return slotType;
    }

    
    public void setSlotType(Integer slotType) {
        this.slotType = slotType;
    }

    
    public Long getSlotMsId() {
        return slotMsId;
    }

    public void setSlotMsId(Long slotMsId) {
        this.slotMsId = slotMsId;
    }

	public Integer getEnableStatus() {
		return enableStatus;
	}

	public void setEnableStatus(Integer enableStatus) {
		this.enableStatus = enableStatus;
	}

	public Integer getCheckStatus() {
		return checkStatus;
	}

	public void setCheckStatus(Integer checkStatus) {
		this.checkStatus = checkStatus;
	}

	public Date getGmtCreate() {
		return gmtCreate;
	}

	public void setGmtCreate(Date gmtCreate) {
		this.gmtCreate = gmtCreate;
	}

	public String getGmtCreateStr() {
		return gmtCreateStr;
	}

	public void setGmtCreateStr(String gmtCreateStr) {
		this.gmtCreateStr = gmtCreateStr;
	}

	public Boolean getValid() {
		return valid;
	}

	public void setValid(Boolean valid) {
		this.valid = valid;
	}

	public Integer getActivityPutWay() {
		return activityPutWay;
	}

	public void setActivityPutWay(Integer activityPutWay) {
		this.activityPutWay = activityPutWay;
	}
}
